==> haskell-type-hint-0.1-25-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-type-hint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 type-hint
version:              0.1
visibility:           public
id:                   type-hint-0.1-GfjRvM73eCDH12lLmmJ0jN
key:                  type-hint-0.1-GfjRvM73eCDH12lLmmJ0jN
license:              BSD-3-Clause
copyright:            2014 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/type-hint
synopsis:             Guide type inference with proxy values
description:
    This package provides '\''Proxy'\'' values for various types from the @base@
    library and functions to use these values as hints for type inference.

category:             Phantom Types
abi:                  706377c383eaae5b159b3fc8bd63f32a
exposed:              True
exposed-modules:      Type.Hint
import-dirs:          /usr/lib/ghc-9.0.1/site-local/type-hint-0.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/type-hint-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/type-hint-0.1
hs-libraries:         HStype-hint-0.1-GfjRvM73eCDH12lLmmJ0jN
depends:              base-4.15.0.0
haddock-interfaces:   /usr/share/doc/haskell-type-hint/html/type-hint.haddock
haddock-html:         /usr/share/doc/haskell-type-hint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-type-hint-0.1-26-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-type-hint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 type-hint
version:              0.1
visibility:           public
id:                   type-hint-0.1-HISDBRoTJRK2Mq187mI2H
key:                  type-hint-0.1-HISDBRoTJRK2Mq187mI2H
license:              BSD-3-Clause
copyright:            2014 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/type-hint
synopsis:             Guide type inference with proxy values
description:
    This package provides '\''Proxy'\'' values for various types from the @base@
    library and functions to use these values as hints for type inference.

category:             Phantom Types
abi:                  d7f95b054d3092c5383489f8282bf8ad
exposed:              True
exposed-modules:      Type.Hint
import-dirs:          /usr/lib/ghc-9.0.2/site-local/type-hint-0.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/type-hint-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/type-hint-0.1
hs-libraries:         HStype-hint-0.1-HISDBRoTJRK2Mq187mI2H
depends:              base-4.15.1.0
haddock-interfaces:   /usr/share/doc/haskell-type-hint/html/type-hint.haddock
haddock-html:         /usr/share/doc/haskell-type-hint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
